
Sardana API
===========

.. rubric:: APIs

.. toctree::
    :maxdepth: 1

    Macro API <api_macro>
    Controller API <api_controller>
    Motor API <api_motor>
    I/O register <api_IOR>
    Counter/timer API <api_countertimer>
    0D experiment channel API <api_0D>
    1D experiment channel API <api_1D>
    2D experiment channel API <api_2D>
    Pseudo motor API <api_pseudomotor>
    Pseudo counter API <api_pseudocounter>
    Pool tango API <tango_device_pool>
    Macro server tango API <tango_macroserver>
    Library <sardana/sardana>
    Test API <api_test>
    
